@@ -2,7 +2,7 @@ from hashlib import new
 import time
 import random
 from pyknow import *
-exeTimes = 32  # time in second
+exeTimes = 30  # time in second
 
 class Greetings(KnowledgeEngine):
     @DefFacts()
@@ -10,8 +10,8 @@ class Greetings(KnowledgeEngine):
         yield Fact(Ticks = 0)
         yield Fact(Second = 0)
         yield Fact(ASecond = False)
-        yield Fact(SwitchTime = 4)
-        yield Fact(Period = 8)
+        yield Fact(SwitchTime = 5)
+        yield Fact(Period = 10)
         yield Fact(NSLight = 'GREEN')
         yield Fact(WELight = 'RED')
         yield Fact(NSCars = 0)
@@ -38,7 +38,7 @@ class Greetings(KnowledgeEngine):
         self.retract(fact1)
         self.retract(fact2)
         self.declare(Fact(Second= times + 1))
-        print(times)
+        print("{}-*-".format(times) )
 
     @Rule(AS.fact1 << Fact(Second=MATCH.times),
           Fact(Period = MATCH.period),
@@ -102,7 +102,12 @@ class Greetings(KnowledgeEngine):
         salience = 2
       )
     def show(self,NScolor,WEcolor):
-        print('\nNS:WE={}:{}\n'.format(NScolor,WEcolor))
+        #print('\n NS:WE={}:{} \n'.format(NScolor,WEcolor))
+        if NScolor == 'RED':
+            print('-X-  -V-')
+        else:
+            print('-V-  -X-')
+
     
     @Rule(
         AS.fact1 << Fact(NSSign = True),
@@ -141,7 +146,8 @@ class Greetings(KnowledgeEngine):
             self.declare(Fact(NSSign = True))
         if random.randint(0,5) == 0 :
             self.declare(Fact(WESign = True))
-        
-engine = Greetings()
-engine.reset()  # Prepare the engine for the execution.
-engine.run()  # Run it!
+
+if __name__ == "__main__":
+    engine = Greetings()
+    engine.reset()  # Prepare the engine for the execution.
+    engine.run()  # Run it!
